@@ -5,7 +5,7 @@
 ***********************************************************************/
 
 #define ASA_ID \
-"/* $Id: asa.c,v 3.13 1994/05/31 11:13:17 ingber Exp ingber $ */"
+"/* $Id: asa.c,v 3.20 1994/10/01 16:45:43 ingber Exp ingber $ */"
 
 #include "asa.h"
 
@@ -15,7 +15,9 @@
 ***********************************************************************/
 #if HAVE_ANSI
 double
-asa (double (*user_cost_function) (),
+asa (double (*user_cost_function) (
+			   double *, double *, double *, double *, double *,
+			  ALLOC_INT *, int *, int *, int *, USER_DEFINES *),
      double (*user_random_generator) (),
      double *parameter_initial_final,
      double *parameter_minimum,
@@ -1311,7 +1313,9 @@ EXIT_ASA:
 ***********************************************************************/
 #if HAVE_ANSI
 void
-asa_exit (double (*user_cost_function) (),
+asa_exit (double (*user_cost_function) (
+			   double *, double *, double *, double *, double *,
+			  ALLOC_INT *, int *, int *, int *, USER_DEFINES *),
 	  double *final_cost,
 	  double *parameter_initial_final,
 	  double *parameter_minimum,
@@ -2166,7 +2170,9 @@ reanneal (parameter_minimum,
 
 #if HAVE_ANSI
 void
-cost_derivatives (double (*user_cost_function) (),
+cost_derivatives (double (*user_cost_function) (
+			   double *, double *, double *, double *, double *,
+			  ALLOC_INT *, int *, int *, int *, USER_DEFINES *),
 		  double *parameter_minimum,
 		  double *parameter_maximum,
 		  double *tangents,
