@@ -5,7 +5,7 @@
 ***********************************************************************/
 
 #define USER_ID \
-"/* $Id: user.c,v 3.13 1994/05/31 11:13:14 ingber Exp ingber $ */"
+"/* $Id: user.c,v 3.20 1994/10/01 16:45:38 ingber Exp ingber $ */"
 
 #include "user.h"
 
@@ -303,10 +303,13 @@ main (argc, argv)
       exit (9);
 #endif
 
-  /* the number of parameters for the cost function */
 #if ASA_TEST
+  /* the number of parameters for the cost function */
   *parameter_dimension = 4;
-#endif
+  /* end ASA_TEST */
+#else /* MY_COST */
+  /* the number of parameters for the cost function */
+#endif /* MY_COST */
 
 #if ASA_SAMPLE
 #if ASA_TEMPLATE
@@ -440,11 +443,8 @@ main (argc, argv)
 #if USER_ASA_OUT
   free (USER_OPTIONS->asa_out_file);
 #endif
-#if USER_COST_SCHEDULE
-  free (USER_OPTIONS->cost_schedule);
-#endif
-#if USER_REANNEAL_FUNCTION
-  free (USER_OPTIONS->reanneal_function);
+#if ASA_SAMPLE
+  free (USER_OPTIONS->bias_generated);
 #endif
   if (USER_OPTIONS->CURVATURE_0 == FALSE || USER_OPTIONS->CURVATURE_0 == -1)
     free (cost_curvature);
@@ -537,7 +537,7 @@ initialize_parameters (cost_parameters,
   ALLOC_INT index;
 
 #if ASA_TEST
-  /* store some parameter ranges */
+  /* store the parameter ranges */
   for (index = 0; index < *parameter_dimension; ++index)
     parameter_lower_bound[index] = -10000.0;
   for (index = 0; index < *parameter_dimension; ++index)
@@ -555,7 +555,12 @@ initialize_parameters (cost_parameters,
       cost_parameters[4 * (index + 1) - 2] = 1001.0;
       cost_parameters[4 * (index + 1) - 1] = -903.0;
     }
-#endif
+  /* end ASA_TEST */
+#else /* MY_COST */
+  /* store the parameter ranges */
+  /* store the initial parameter types */
+  /* store the initial parameter values */
+#endif /* MY_COST */
 
 #if ASA_SAMPLE
 #if ASA_TEMPLATE
@@ -788,7 +793,10 @@ cost_function (x,
 #endif
 #endif
   return (q_n);
-#endif /* ASA_TEST */
+  /* end ASA_TEST */
+#else /* MY_COST */
+  /* use the parameter values x[] to define your cost function */
+#endif /* MY_COST */
 
 #if ASA_SAMPLE
 #if ASA_TEMPLATE
@@ -919,7 +927,7 @@ user_cost_schedule (test_temperature,
 
 #if ASA_SAMPLE
 #if ASA_TEMPLATE
-  x = pow (test_temperature, 0.5);
+  x = pow (test_temperature, 0.25);
 #endif
 
 #else
@@ -1316,11 +1324,8 @@ main (argc, argv)
 #if USER_ASA_OUT
   free (RECUR_USER_OPTIONS->asa_out_file);
 #endif
-#if USER_COST_SCHEDULE
-  free (RECUR_USER_OPTIONS->cost_schedule);
-#endif
-#if USER_REANNEAL_FUNCTION
-  free (RECUR_USER_OPTIONS->reanneal_function);
+#if ASA_SAMPLE
+  free (RECUR_USER_OPTIONS->bias_generated);
 #endif
   if (RECUR_USER_OPTIONS->CURVATURE_0 == FALSE
       || RECUR_USER_OPTIONS->CURVATURE_0 == -1)
@@ -1607,9 +1612,13 @@ recur_cost_function (x,
   if ((cost_flag = (int *) calloc (1, sizeof (int))) == NULL)
       exit (9);
 
-#if ASA_TEST			/* if using SELF_OPTIMIZE=ASA_TEST=TRUE */
+#if ASA_TEST
+  /* set parameter dimension if SELF_OPTIMIZE=TRUE */
   *parameter_dimension = 4;
-#endif
+  /* end ASA_TEST */
+#else /* MY_COST */
+  /* set parameter dimension if SELF_OPTIMIZE=TRUE */
+#endif /* MY_COST */
 
   if ((parameter_lower_bound =
        (double *) calloc (*parameter_dimension, sizeof (double))
@@ -1765,11 +1774,8 @@ recur_cost_function (x,
 #if USER_ASA_OUT
   free (USER_OPTIONS->asa_out_file);
 #endif
-#if USER_COST_SCHEDULE
-  free (USER_OPTIONS->cost_schedule);
-#endif
-#if USER_REANNEAL_FUNCTION
-  free (USER_OPTIONS->reanneal_function);
+#if ASA_SAMPLE
+  free (USER_OPTIONS->bias_generated);
 #endif
   if (USER_OPTIONS->CURVATURE_0 == FALSE || USER_OPTIONS->CURVATURE_0 == -1)
     free (cost_curvature);
